@@ -3,7 +3,7 @@
 #include "QueueView.h"
 
 
-QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, MCEWrapper *pMCEWrapper, QWidget* parent)
+QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, DBusWrapper *pDBusWrapper, QWidget* parent)
     : QMainWindow(parent)
 {
     //construct the QueueView UI
@@ -15,30 +15,28 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, MCEWrapper
     setWindowTitle(tr("Now Playing"));
 
     m_pSession = pSession; //set the Spotify session instance
+    m_playing = false; //set initial playback state
+    m_userInitiatedPause = false;
+    m_pauseOnHsetUnplugged = false;
+    m_update = false;
+    m_lastTimeTrackActivated = QTime::currentTime(); //set to current time
+    m_CallerID = QUEUEVIEW_ID;
 
     m_pAlbumCoverContainer = new Spotify::ImageContainer(this); //allocate coverart imagecontainer instance
     connect(m_pAlbumCoverContainer,SIGNAL(loaded()),SLOT(OnAlbumCoverLoaded()));
 
-    m_playing = false; //set initial playback state
-
-    m_userInitiatedPause = false;
-
-    m_update = false;
-
-    m_lastTimeTrackActivated = QTime::currentTime(); //set to current time
-
-    m_CallerID = QUEUEVIEW_ID;
-
     m_pOssoWrapper = pOsso; //set OssoWrapper instance pointer
     if(m_pOssoWrapper)
     {
         connect(m_pOssoWrapper,SIGNAL(playbackStateChangeRequest(pb_state_e)),SLOT(OnPlaybackStateChangeRequest(pb_state_e)));
     }
 
-    m_pMCEWrapper = pMCEWrapper; //set MCE D-bus wrapper instance pointer
-    if(m_pMCEWrapper)
+    m_pDBusWrapper = pDBusWrapper; //set D-bus wrapper instance pointer
+    if(m_pDBusWrapper)
     {
-       connect(m_pMCEWrapper,SIGNAL(onDisplayStateChange(bool)),SLOT(OnDisplayStateChanged(bool)));
+       connect(m_pDBusWrapper,SIGNAL(onDisplayStateChange(bool)),SLOT(OnDisplayStateChanged(bool)));
+       connect(m_pDBusWrapper,SIGNAL(onHalButtonPressed(const QString&)),SLOT(OnHalButtonPressed(const QString&)));
+       connect(m_pDBusWrapper,SIGNAL(onHeadsetRemoved()),SLOT(OnHeadsetRemoved()));
     }
 
     m_pCurrTrack = NULL;
@@ -91,6 +89,7 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, MCEWrapper
     connect(&m_NextBtn,SIGNAL(clicked()),SLOT(OnNextTrackBtn()));
     connect(menuBar(),SIGNAL(triggered(QAction*)),SLOT(OnMenubarAction(QAction*)));
     connect(QApplication::desktop(), SIGNAL(resized(int)),SLOT(OnOrientationChanged()));
+   // connect(m_pProgressSlider,SIGNAL(positionChanged(int)),SLOT(OnProgressSliderClicked(int)));
 
     m_AlbumCover.setFixedSize(QUEUEVIEW_COVERART_WIDTH_LANDSCAPE,QUEUEVIEW_COVERART_HEIGHT_LANDSCAPE); //set fixed size of the album coverart
 
@@ -104,15 +103,15 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, MCEWrapper
             "QPushButton {max-width: 100px;}"
             "QPushButton {min-width: 100px;}"
             "QPushButton {border-style: none;}"
-            "QPushButton {background-image: url(/usr/share/images/play.png);}"
-            "QPushButton:on {background-image: url(/usr/share/images/pause.png);}"
-            "QPushButton:pressed {background-image: url(/usr/share/images/play-on.png);}");
+            "QPushButton {background-image: url(/opt/qspot/images/play.png);}"
+            "QPushButton:on {background-image: url(/opt/qspot/images/pause.png);}"
+            "QPushButton:pressed {background-image: url(/opt/qspot/images/play-on.png);}");
 
-    m_PrevBtn.setStyleSheet("QPushButton {min-width: 80px; min-height: 44px; max-width: 80px; max-height: 44px; border-style: none; background-image: url(/usr/share/images/previous.png);}"
-                            "QPushButton:pressed {background-image: url(/usr/share/images/previous-on.png);}");
+    m_PrevBtn.setStyleSheet("QPushButton {min-width: 80px; min-height: 44px; max-width: 80px; max-height: 44px; border-style: none; background-image: url(/opt/qspot/images/previous.png);}"
+                            "QPushButton:pressed {background-image: url(/opt/qspot/images/previous-on.png);}");
 
-    m_NextBtn.setStyleSheet("QPushButton {min-width: 80px; min-height: 44px; max-width: 80px; max-height: 44px;border-style: none; background-image: url(/usr/share/images/next.png);}"
-                            "QPushButton:pressed {background-image: url(/usr/share/images/next-on.png);}");
+    m_NextBtn.setStyleSheet("QPushButton {min-width: 80px; min-height: 44px; max-width: 80px; max-height: 44px;border-style: none; background-image: url(/opt/qspot/images/next.png);}"
+                            "QPushButton:pressed {background-image: url(/opt/qspot/images/next-on.png);}");
 
     m_ShuffleBtn.setCheckable(true);
 
@@ -122,8 +121,8 @@ QueueView::QueueView(Spotify::Session* pSession, OssoWrapper* pOsso, MCEWrapper
             "QPushButton {max-width: 60px;}"
             "QPushButton {min-width: 60px;}"
             "QPushButton {border-style: none;}"
-            "QPushButton {background-image: url(/usr/share/images/shuffle.png);}"
-            "QPushButton:on {background-image: url(/usr/share/images/shuffle-down.png);}");
+            "QPushButton {background-image: url(/opt/qspot/images/shuffle.png);}"
+            "QPushButton:on {background-image: url(/opt/qspot/images/shuffle-down.png);}");
 
     m_pPlayerControlsHoriz = new QGridLayout();
 
@@ -188,6 +187,11 @@ void QueueView::setupContextMenu()
     m_pTrackInfoView->addAction(pViewArtistAct);
 }
 
+void QueueView::setPauseOnHSUnplugged(bool state)
+{
+    //public method for setting the headset unplugged state (i.e., whether playback should be paused when headset is unplugged)
+    m_pauseOnHsetUnplugged = state;
+}
 
 void QueueView::setupMenubar()
 {
@@ -420,7 +424,7 @@ void QueueView::addTracks(QList<Spotify::Track*> trackList)
     QPixmap iconMap;
     QString strSubHeader;
 
-    iconMap.load("/usr/share/images/icon-type-song-color.png"); //load song (track) type icon from file
+    iconMap.load("/opt/qspot/images/icon-type-song-color.png"); //load song (track) type icon from file
 
     QIcon trackTypeIcon(iconMap);
 
@@ -588,6 +592,7 @@ void QueueView::OnPlaybackPositionUpdated(qint64 playbackPos)
 
         int currPos = (playbackPos*m_currSliderWidth) / (m_currTrackDuration*1000);
 
+
         m_pProgressSlider->setPos2(currPos); //set curr. slider position
     }
 }
@@ -1091,3 +1096,60 @@ void QueueView::OnDisplayStateChanged(bool state)
         m_pSpectrum->Stop();
     }
 }
+
+void QueueView::OnHalButtonPressed(const QString& value)
+{
+    //button pressed notification (condition) received from HAL (device)
+
+    if(m_pCurrTrack) //track currently loaded
+    {
+        if(value=="pause-cd"||value=="play-cd")
+        {
+            //pause / resume current playback (request from e.g., BT headset)
+            pauseResumePlayback();
+        }
+        else if(value=="next-song")
+        {
+            //skip to next track
+            OnNextTrackBtn();
+        }
+        else if(value=="previous-song")
+        {
+            //skip to previous track
+            OnPrevTrackBtn();
+        }
+    }
+}
+
+void QueueView::OnHeadsetRemoved()
+{
+    //Headset removed notification received from Hal device manager    
+    if(m_pauseOnHsetUnplugged && m_playing)
+    { //in case music playback is in progress (and option to pause on headset unplugged active); pause music playback
+        pauseResumePlayback();
+    }
+}
+
+/*void QueueView::OnProgressSliderClicked(int pos)
+{
+    //progress slider has been clicked (pos=clicked position)
+    double seekPos;
+
+    if(m_pCurrTrack)
+    {
+        //we have a track loaded, calculate corresponding position within the track (in msecs)
+        seekPos = ((pos*m_currTrackDuration*1000) / m_currSliderWidth);
+        qDebug() << "Request to seek to position " << seekPos << " msecs within track";
+        if(m_currQueuePos != m_currQueueBuffPos)
+        {
+            //we are currently buffering and playing different tracks
+              m_currQueueBuffPos = m_currQueuePos;
+              playTrack(m_pCurrTrack);
+        }
+        m_pSession->seek(seekPos); //seek to specified position within the stream
+        m_pProgressSlider->setPos1(pos);
+        m_pProgressSlider->setPos2(pos);
+    }
+}
+*/
+
