@@ -39,6 +39,22 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 
     m_BufferingOptions.setLayout(&m_BufferingOptionLayout);
 
+    //set up UI language value button / selector
+
+    QStringListModel *pLangListModel = new QStringListModel(this);
+
+    m_UILangList << "English" << "Suomi"; //possible UI language values
+
+    m_UILangCodeList << "en" << "fi"; //corresponding internal language codes
+
+    pLangListModel->setStringList(m_UILangList);
+
+    m_pUILangSelector = new QMaemo5ListPickSelector(this);
+
+    m_pUILangSelector->setModel(pLangListModel);
+    m_UILangBtn.setValueLayout(QMaemo5ValueButton::ValueUnderTextCentered); // Maemo5 style guide wants the menu entries centered.
+    m_UILangBtn.setPickSelector(m_pUILangSelector);
+
     //set up screen orientation value button / selector
 
     QStringListModel *pListModel = new QStringListModel(this);
@@ -74,10 +90,11 @@ SettingsDialog::SettingsDialog(QSettings* pSettings, QWidget* pParent)
 
     m_GridLayout.addWidget(&m_SearchOptions,0,0,1,-1);
     m_GridLayout.addWidget(&m_BufferingOptions,1,0,1,-1);
-    m_GridLayout.addWidget(&m_OrientationBtn,2,0,1,-1);
-    m_GridLayout.addWidget(&m_PlaylistOptions,3,0,1,-1);
-    m_GridLayout.addWidget(&m_PauseOnHSDisconnSelection,4,0,1,-1);
-    m_GridLayout.addWidget(&m_ScrobblingOptions,5,0,1,-1);
+    m_GridLayout.addWidget(&m_UILangBtn,2,0,1,-1);
+    m_GridLayout.addWidget(&m_OrientationBtn,3,0,1,-1);
+    m_GridLayout.addWidget(&m_PlaylistOptions,4,0,1,-1);
+    m_GridLayout.addWidget(&m_PauseOnHSDisconnSelection,5,0,1,-1);
+    m_GridLayout.addWidget(&m_ScrobblingOptions,6,0,1,-1);
 
     m_MainAreaLayout.setLayout(&m_GridLayout);
     m_MainArea.setWidget(&m_MainAreaLayout);
@@ -106,6 +123,7 @@ void SettingsDialog::setCapsLandscape()
     m_BufferingOptions.setTitle(tr("Buffering settings"));
     m_MinBufferLenCaption.setText(tr("Min. buffering length (secs)"));
     m_PreBufferNextTrackSelection.setText(tr("Enable track pre-buffering"));
+    m_UILangBtn.setText(tr("UI Language"));
     m_OrientationBtn.setText(tr("Display orientation"));
     m_PlaylistOptions.setTitle(tr("Playlist options"));
     m_PlaylistLoadingTOCaption.setText(tr("Playlist load timeout (secs)"));
@@ -129,6 +147,7 @@ void SettingsDialog::setCapsPortrait()
     m_BufferingOptions.setTitle(tr("Buffering settings"));
     m_MinBufferLenCaption.setText(tr("Min.buff.length (secs)"));
     m_PreBufferNextTrackSelection.setText(tr("Enable track pre-buff."));
+    m_UILangBtn.setText(tr("UI Language"));
     m_OrientationBtn.setText(tr("Display orientation"));
     m_PlaylistOptions.setTitle(tr("Playlist options"));
     m_PlaylistLoadingTOCaption.setText(tr("Playlist load TO (secs)"));
@@ -168,6 +187,9 @@ void SettingsDialog::readSettings()
         else
             m_PreBufferNextTrackSelection.setChecked(false);
 
+        m_currUILang = m_UILangCodeList.indexOf(m_pAppSettings->value("QSpot/language",LANG_DEFAULT).toString());
+        m_pUILangSelector->setCurrentIndex(m_currUILang);
+
         m_currOrientation = m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt();
 
         m_pOrientationSelector->setCurrentIndex(m_currOrientation);
@@ -247,6 +269,12 @@ void SettingsDialog::saveSettings()
             settingsChanged = true;
         }
 
+        if(m_pUILangSelector->currentIndex()!=m_currUILang)
+        {
+            m_pAppSettings->setValue("QSpot/language",m_UILangCodeList.at(m_pUILangSelector->currentIndex()));
+            QMaemo5InformationBox::information(this,tr("Please restart QSpot for language change to take effect!"));
+        }
+
         if(m_pOrientationSelector->currentIndex()!=m_currOrientation)
         {
             m_pAppSettings->setValue("QSpot/displayOrientation",m_pOrientationSelector->currentIndex());
