@@ -19,6 +19,7 @@
 #include <QStringListModel>
 #include <QMaemo5ListPickSelector>
 #include <QMaemo5ValueButton>
+#include <QMaemo5InformationBox>
 #include "global_defs.h"
 
 
@@ -33,6 +34,7 @@
 #define ORIENTATION_DEFAULT 0
 #define PLAYLIST_LOADING_TO_DEFAULT 30
 #define PAUSE_ON_HEADSET_UNPLUG_DEFAULT 0
+#define LANG_DEFAULT "en"
 
 
 class SettingsDialog : public QDialog
@@ -87,6 +89,14 @@ private:
     QLabel m_MinBufferLenCaption;
     QLineEdit m_MinBufferLenInput;  //min. buffer length used (in secs)
 
+    QMaemo5ValueButton m_UILangBtn; //value type button for selecting current UI language
+
+    QStringList m_UILangList; //list of possible UI language values (e.g., English)
+
+    QStringList m_UILangCodeList; //internal list of corresponding UI language codes (e.g., en for English)
+
+    QMaemo5ListPickSelector *m_pUILangSelector; //pick selector associated with UI language button
+
     QCheckBox m_PreBufferNextTrackSelection; //selected if automatic buffering of next track should be activated
 
     QStringList m_orientationList; //list of device orientation values
@@ -130,6 +140,8 @@ private:
 
     qint32 m_enableScrobbling;
 
+    qint32 m_currUILang;
+
     QString m_strLastFMUserID;
 
     QString m_strLastFMPassword;
