@@ -9,7 +9,11 @@ MainWindow::MainWindow(QWidget *parent)
 #endif
 
     QCoreApplication::setApplicationName("QSpot"); //Setup app name
-    QCoreApplication::setApplicationVersion(APP_VERSION);
+    QCoreApplication::setApplicationVersion(APP_VERSION); //Setup app version
+
+    m_pAppSettings = new QSettings("qspot","qspot", this); //allocate application settings instance
+
+    setupUILang(); //setup the UI language
 
     setWindowTitle(tr("QSpot - Playlists"));
 
@@ -50,8 +54,6 @@ MainWindow::MainWindow(QWidget *parent)
     m_pTimeoutTimer  = new QTimer(this); //timeout timer instance
     connect(m_pTimeoutTimer,SIGNAL(timeout()),SLOT(OnPlaylistLoadingTimeout()));
 
-    m_pAppSettings = new QSettings("qspot","qspot", this); //allocate application settings instance
-
     m_pLoginDlg = new LoginDialog(m_pSession,m_pAppSettings, this); //allocate login dialog instance
 
     m_pSettingsDlg = new SettingsDialog(m_pAppSettings, this); //allocate settings dialog instance
@@ -162,6 +164,14 @@ MainWindow::MainWindow(QWidget *parent)
     emit showLogin(); //emit signal requesting to show login dialog
 }
 
+void MainWindow::setupUILang()
+{
+    //setup the UI language (localisation)
+    m_appTranslator.load("/opt/qspot/translations/qspot_" + m_pAppSettings->value("QSpot/language",LANG_DEFAULT).toString());
+    qApp->installTranslator(&m_appTranslator);
+}
+
+
 void MainWindow::initAboutDialog()
 {
     //init the application about dialog
