@@ -23,6 +23,7 @@
 #include <QMessageBox>
 #include <QFont>
 #include <QTimer>
+#include <QTranslator>
 #include <QtMaemo5/QMaemo5InformationBox>
 #include <qspotify_src/spotifysession.h>
 #include "logindialog.h"
@@ -42,7 +43,7 @@
 
 //defines
 
-#define APP_VERSION "0.9.0-3" //application version string
+#define APP_VERSION "0.9.0-4" //application version string
 
 class MainWindow : public QMainWindow
 {
@@ -65,6 +66,8 @@ private:
 
     QGridLayout m_GridLayout;
 
+    QTranslator m_appTranslator;
+
     LoginDialog* m_pLoginDlg;
 
     SettingsDialog* m_pSettingsDlg;
@@ -139,6 +142,8 @@ private:
 
     void setDisplayOrientation(qint32 orientation); //set the display orientation
 
+    void setupUILang(); //setup the UI language
+
 
 
 private slots:
