@@ -371,11 +371,19 @@ Spotify::Error Spotify::Session::play( Spotify::Track* track, bool preBuffer )
     return Spotify::Error( SP_ERROR_OK );
 }
 
-Spotify::Error Spotify::Session::seek( int pos )
+Spotify::Error Spotify::Session::seek( qint32 pos )
 {
+    //Seek to specified position (pos) within the currenly loaded track. Pos is specified in msecs.
+
+    m_playbackPos = pos;
+    m_bufferedAmount = pos;
+    m_pAudioThread->getMutex()->lock();
+    m_pAudioThread->flushPAbuffer(); //flush pulseaudio internal buffer
+    m_pAudioThread->clearFIFO();
+    m_pAudioThread->setFIFOSize(0);
+    m_pAudioThread->getMutex()->unlock();
+
     Spotify::Error error = sp_session_player_seek( m_session, pos );
-    if( !error.isError() )
-        m_playbackPos = pos;
     return error;
  }
 
