@@ -114,10 +114,10 @@ namespace Spotify
 
             /**
              * Seek to a given position in the stream.
-             * @param pos Position to seek to.
+             * @param pos Position to seek to (in msecs).
              * @return Error
              */
-            Spotify::Error seek( int pos );
+            Spotify::Error seek( qint32 pos );
 
             /**
              * Stop playback.
