@@ -123,35 +123,35 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="14"/>
+        <location filename="../src/MainWindow.cpp" line="18"/>
         <source>QSpot - Playlists</source>
         <translation>QSpot - Soittolistat</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="60"/>
-        <location filename="../src/MainWindow.cpp" line="560"/>
+        <location filename="../src/MainWindow.cpp" line="62"/>
+        <location filename="../src/MainWindow.cpp" line="570"/>
         <source>Settings</source>
         <translation>Asetukset</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="61"/>
-        <location filename="../src/MainWindow.cpp" line="566"/>
+        <location filename="../src/MainWindow.cpp" line="63"/>
+        <location filename="../src/MainWindow.cpp" line="576"/>
         <source>FM Transmitter</source>
         <translation>FM-lähetin</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="62"/>
-        <location filename="../src/MainWindow.cpp" line="570"/>
+        <location filename="../src/MainWindow.cpp" line="64"/>
+        <location filename="../src/MainWindow.cpp" line="580"/>
         <source>About</source>
         <translation>Tietoa</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="169"/>
+        <location filename="../src/MainWindow.cpp" line="179"/>
         <source>About QSpot</source>
         <translation>Tietoa QSpotista</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="171"/>
+        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>QSpot version </source>
         <translation>QSpot-versio</translation>
     </message>
@@ -168,7 +168,7 @@ Special thanks to Markus (markusm@tmo) for assistance with the graphical design
 Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnitteelussa ja ulkoasussa.</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="171"/>
+        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>An open-source Qt-based Spotify client for the N900/Maemo5 (based on libopenspotify).
 
 (C) 2011 Andreas Enbacka and The QSpot Team.
@@ -181,48 +181,48 @@ Special thanks to Markus (markusm@tmo) for assistance with the graphical design
 Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnittelussa ja ulkoasussa sekä Tomille (rantom@tomi) suomenkielelle kääntämisestä.</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="396"/>
+        <location filename="../src/MainWindow.cpp" line="406"/>
         <source>Error:</source>
         <translation>Virhe:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="409"/>
+        <location filename="../src/MainWindow.cpp" line="419"/>
         <source>Loading playlists</source>
         <translation>Ladataan soittolistoja</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="426"/>
+        <location filename="../src/MainWindow.cpp" line="436"/>
         <source>Timeout occured while loading playlists!</source>
         <translation>Soittolistoja ladatessa tapahtui aikakatkaisu!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="454"/>
+        <location filename="../src/MainWindow.cpp" line="464"/>
         <source>tracks</source>
-        <translation>kappaleet</translation>
+        <translation>kappaletta</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="592"/>
+        <location filename="../src/MainWindow.cpp" line="602"/>
         <source>Searching</source>
-        <translation>Haetaan</translation>
+        <translation>Etsitään</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="598"/>
-        <location filename="../src/MainWindow.cpp" line="613"/>
+        <location filename="../src/MainWindow.cpp" line="608"/>
+        <location filename="../src/MainWindow.cpp" line="623"/>
         <source>Error: </source>
         <translation>Virhe:</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="632"/>
+        <location filename="../src/MainWindow.cpp" line="642"/>
         <source>No tracks found!</source>
         <translation>Ei löytynyt kappaleita!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="646"/>
+        <location filename="../src/MainWindow.cpp" line="656"/>
         <source>Playback paused due to the same account being used somewhere else!</source>
         <translation>Toisto keskeytettiin, koska tunnus on auki toisella koneella!</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="656"/>
+        <location filename="../src/MainWindow.cpp" line="666"/>
         <source>Last.fm error: </source>
         <translation>Last.fm-virhe: </translation>
     </message>
@@ -298,150 +298,161 @@ Erityiskiitokset Markukselle (markus@tmo) avusta graafisessa suunnittelussa ja u
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="46"/>
+        <location filename="../src/SettingsDialog.cpp" line="62"/>
         <source>Landscape</source>
         <translation>Vaaka</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="46"/>
+        <location filename="../src/SettingsDialog.cpp" line="62"/>
         <source>Portrait</source>
         <translation>Pysty</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="46"/>
+        <location filename="../src/SettingsDialog.cpp" line="62"/>
         <source>Automatic</source>
         <translation>Automaattinen</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="101"/>
-        <location filename="../src/SettingsDialog.cpp" line="124"/>
+        <location filename="../src/SettingsDialog.cpp" line="118"/>
+        <location filename="../src/SettingsDialog.cpp" line="142"/>
         <source>QSpot - Settings</source>
         <translation>QSpot - Asetukset</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="102"/>
+        <location filename="../src/SettingsDialog.cpp" line="119"/>
         <source>Max. tracks returned</source>
         <translation>Max. kappaleita tuotu</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="103"/>
+        <location filename="../src/SettingsDialog.cpp" line="120"/>
         <source>Max. albums returned</source>
         <translation>Max. albumeita tuotu</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="104"/>
+        <location filename="../src/SettingsDialog.cpp" line="121"/>
         <source>Max. artists returned</source>
         <translation>Max. artisteja tuotu</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="105"/>
-        <location filename="../src/SettingsDialog.cpp" line="128"/>
+        <location filename="../src/SettingsDialog.cpp" line="122"/>
+        <location filename="../src/SettingsDialog.cpp" line="146"/>
         <source>Search settings</source>
         <translation>Haun asetukset</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="106"/>
-        <location filename="../src/SettingsDialog.cpp" line="129"/>
+        <location filename="../src/SettingsDialog.cpp" line="123"/>
+        <location filename="../src/SettingsDialog.cpp" line="147"/>
         <source>Buffering settings</source>
         <translation>Puskuroinnin asetukset</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="107"/>
+        <location filename="../src/SettingsDialog.cpp" line="124"/>
         <source>Min. buffering length (secs)</source>
         <translation>Vähimmäis-puskuroinnin pituus (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="108"/>
+        <location filename="../src/SettingsDialog.cpp" line="125"/>
         <source>Enable track pre-buffering</source>
         <translation>Salli kappaleen esi-puskurointi</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="109"/>
-        <location filename="../src/SettingsDialog.cpp" line="132"/>
+        <location filename="../src/SettingsDialog.cpp" line="126"/>
+        <location filename="../src/SettingsDialog.cpp" line="150"/>
+        <source>UI Language</source>
+        <translation>Käytettävä kieli</translation>
+    </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="127"/>
+        <location filename="../src/SettingsDialog.cpp" line="151"/>
         <source>Display orientation</source>
         <translation>Näytön suunta</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="110"/>
-        <location filename="../src/SettingsDialog.cpp" line="133"/>
+        <location filename="../src/SettingsDialog.cpp" line="128"/>
+        <location filename="../src/SettingsDialog.cpp" line="152"/>
         <source>Playlist options</source>
         <translation>Soittolistan valinnat</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="111"/>
+        <location filename="../src/SettingsDialog.cpp" line="129"/>
         <source>Playlist load timeout (secs)</source>
         <translation>Soittolistan latauksen aikakatkaisu (sekunteina)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="112"/>
-        <location filename="../src/SettingsDialog.cpp" line="135"/>
+        <location filename="../src/SettingsDialog.cpp" line="130"/>
+        <location filename="../src/SettingsDialog.cpp" line="154"/>
         <source>Pause on headset unplugged</source>
         <translation>Keskeytä toisto kuulokkeiden irrotessa</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="113"/>
-        <location filename="../src/SettingsDialog.cpp" line="136"/>
+        <location filename="../src/SettingsDialog.cpp" line="131"/>
+        <location filename="../src/SettingsDialog.cpp" line="155"/>
         <source>Scrobbling options</source>
         <translation>Julkistamisasetukset</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="114"/>
+        <location filename="../src/SettingsDialog.cpp" line="132"/>
         <source>Enable scrobbling to Last.fm</source>
         <translation>Salli kappaleiden julkistaminen Last.fm:lle</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="115"/>
-        <location filename="../src/SettingsDialog.cpp" line="138"/>
+        <location filename="../src/SettingsDialog.cpp" line="133"/>
+        <location filename="../src/SettingsDialog.cpp" line="157"/>
         <source>Last.fm username</source>
         <translation>Last.fm-tunnus</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="116"/>
-        <location filename="../src/SettingsDialog.cpp" line="139"/>
+        <location filename="../src/SettingsDialog.cpp" line="134"/>
+        <location filename="../src/SettingsDialog.cpp" line="158"/>
         <source>Last.fm password</source>
         <translation>Last.fm-salasana</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="117"/>
-        <location filename="../src/SettingsDialog.cpp" line="140"/>
+        <location filename="../src/SettingsDialog.cpp" line="135"/>
+        <location filename="../src/SettingsDialog.cpp" line="159"/>
         <source>Save</source>
         <translation>Tallenna</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="125"/>
+        <location filename="../src/SettingsDialog.cpp" line="143"/>
         <source>Max. tracks</source>
         <translation>Kappaleita enintään</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="126"/>
+        <location filename="../src/SettingsDialog.cpp" line="144"/>
         <source>Max. albums</source>
         <translation>Albumeja enintään</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="127"/>
+        <location filename="../src/SettingsDialog.cpp" line="145"/>
         <source>Max. artists</source>
         <translation>Artisteja enintään</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="130"/>
+        <location filename="../src/SettingsDialog.cpp" line="148"/>
         <source>Min.buff.length (secs)</source>
         <translation>Vähimmäis-puskurointi (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="131"/>
+        <location filename="../src/SettingsDialog.cpp" line="149"/>
         <source>Enable track pre-buff.</source>
         <translation>Salli kappaleen esi-puskurointi.</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="134"/>
+        <location filename="../src/SettingsDialog.cpp" line="153"/>
         <source>Playlist load TO (secs)</source>
         <translation>Soittolistan latauksen aikakatkaisu (sek.)</translation>
     </message>
     <message>
-        <location filename="../src/SettingsDialog.cpp" line="137"/>
+        <location filename="../src/SettingsDialog.cpp" line="156"/>
         <source>Enable Last.fm scrobbling</source>
         <translation>Salli Last.fm:lle julkistaminen</translation>
     </message>
+    <message>
+        <location filename="../src/SettingsDialog.cpp" line="275"/>
+        <source>Please restart QSpot for language change to take effect!</source>
+        <translation>Käynnistä QSpot uudelleen ottaaksesi käyttöön kieliasetuksen muutokset!</translation>
+    </message>
 </context>
 <context>
     <name>Spotify::Album</name>
